from setuptools import setup, find_packages 
from pathlib import Path 

# Read the contents of the README file 
this_directory = Path(__file__).parent 
long_description = (this_directory / "README.md").read_text()

setup(
    name='qdesc',
    version='1.0.9.7',
    packages=find_packages(),
    install_requires=[
        'pandas',
        'numpy',
        'scipy>=1.17',
        'seaborn',
        'matplotlib',
        'statsmodels'
    ],
    author='Paolo Hilado',
    author_email='datasciencepgh@proton.me',
    description= 'Quick and Easy way to do descriptive analysis.',
    url= "https://github.com/Dcroix/qdesc",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    long_description=long_description, 
    long_description_content_type='text/markdown',
)
